==> xscorch_0.1.14.orig.tar.gz: xscorch-0.1.14/sgtk/swidgets/slinkcombo.h <==
/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/slinkcombo.h,v 1.2 2001/04/07 19:46:50 justins Exp $ */
/*
   
   xscorch - slinkcombo.h     Copyright(c) 2001,2000 Justin David Smith
   justins(at)chaos2.org      http://chaos2.org/
    
   Scorch combolist widgets
    

   This program is free software; you can redistribute it and/or modify 
   it under the terms of the GNU General Public License as published by 
   the Free Software Foundation; either version 2 of the License, or 
   (at your option) any later version.

   This program is distributed in the hope that it will be useful, 
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
#ifndef __slinkcombo_h_included
#define __slinkcombo_h_included


#include <gtk/gtk.h>
#include <gtk/gtkcombo.h>


/* typecasts */
#define  SC_LINK_COMBO(obj)          GTK_COMBO_CAST(obj, sc_link_combo_get_type(), ScLinkCombo)
#define  SC_LINK_COMBO_CLASS(klass)  GTK_COMBO_CLASS_CAST(klass, sc_link_combo_get_type(), ScLinkComboClass)
#define  IS_SC_LINK_COMBO(obj)       GTK_COMBO_TYPE(obj, sc_link_combo_get_type())


/* The ScLinkCombo structure */
typedef struct _ScLinkCombo {
   GtkCombo parent;
   int *value;
} ScLinkCombo;


/* ScLinkComboClass structure */
typedef struct _ScLinkComboClass {
   GtkComboClass parent_class;
   void (*modified)(ScLinkCombo *spin, gpointer data);
} ScLinkComboClass;


/* LinkCombo initialisation and execution */
GtkType sc_link_combo_get_type(void);
GtkWidget *sc_link_combo_new(int *value, const char **entries);


#endif /* __slinkcombo_h_included */

==> xscorch_0.2.0.orig.tar.gz: xscorch-0.2.0/sgtk/swidgets/slinkcombo.h <==
/* $Header: /fridge/cvs/xscorch/sgtk/swidgets/slinkcombo.h,v 1.5 2004/02/26 06:34:56 justins Exp $ */
/*

   xscorch - slinkcombo.h     Copyright(c) 2000-2003 Justin David Smith
   justins(at)chaos2.org      http://chaos2.org/

   Scorch combolist widgets


   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, version 2 of the License ONLY.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
#ifndef __slinkcombo_h_included
#define __slinkcombo_h_included


#include <sgtk.h>
#include <gtk/gtk.h>
#include <gtk/gtkcombo.h>


/* typecasts */
#define  SC_LINK_COMBO(obj)          GTK_COMBO_CAST(obj, sc_link_combo_get_type(), ScLinkCombo)
#define  SC_LINK_COMBO_CLASS(klass)  GTK_COMBO_CLASS_CAST(klass, sc_link_combo_get_type(), ScLinkComboClass)
#define  IS_SC_LINK_COMBO(obj)       GTK_COMBO_TYPE(obj, sc_link_combo_get_type())


/* The ScLinkCombo structure */
typedef struct _ScLinkCombo {
   GtkCombo parent;
   int *value;
} ScLinkCombo;


/* ScLinkComboClass structure */
typedef struct _ScLinkComboClass {
   GtkComboClass parent_class;
   void (*modified)(ScLinkCombo *spin, gpointer data);
} ScLinkComboClass;


/* LinkCombo initialisation and execution */
GType sc_link_combo_get_type(void);
GtkWidget *sc_link_combo_new(int *value, const char **entries);


#endif /* __slinkcombo_h_included */
